use crate::energy::energy_actor;
use crate::server::custom_error::HttpResult;
use crate::server::WebEnergyActor;
use actix_web::HttpResponse;

/// Get the list of pending (not accepted yet) devices
pub async fn list_pending(actor: WebEnergyActor) -> HttpResult {
    let list = actor
        .send(energy_actor::GetDeviceLists)
        .await?
        .into_iter()
        .filter(|d| !d.validated)
        .collect::<Vec<_>>();

    Ok(HttpResponse::Ok().json(list))
}

/// Get the list of validated (not accepted yet) devices
pub async fn list_validated(actor: WebEnergyActor) -> HttpResult {
    let list = actor
        .send(energy_actor::GetDeviceLists)
        .await?
        .into_iter()
        .filter(|d| d.validated)
        .collect::<Vec<_>>();

    Ok(HttpResponse::Ok().json(list))
}
